import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:factory_signage_app/const/colors.dart';
import 'package:factory_signage_app/const/dimens.dart';
import 'package:factory_signage_app/widget/camera.dart';
import 'package:factory_signage_app/widget/daily_graph.dart';
import 'package:factory_signage_app/widget/header.dart';
import 'package:factory_signage_app/widget/lines.dart';
import 'package:factory_signage_app/widget/product_number.dart';
import 'package:factory_signage_app/widget/schedule.dart';
import 'package:factory_signage_app/widget/video.dart';
import 'package:factory_signage_app/widget/weekly_graph.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(),
    );
  }
}

class MyHomePage extends StatelessWidget {
  const MyHomePage({super.key});

  @override
  Widget build(BuildContext context) {
    final Size deviceSize = MediaQuery.of(context).size;

    return Scaffold(
      extendBodyBehindAppBar: true,
      backgroundColor: bodyBackgroundColor,
      body: ProviderScope(
        child: Column(
          children: [
            Container(
              padding: EdgeInsets.only(
                left: deviceSize.width * headerEdgeWidthPaddingRatio,
                right: deviceSize.width * headerEdgeWidthPaddingRatio,
              ),
              child: Header(
                size: Size(
                  double.infinity,
                  deviceSize.height * headerHeightRatio,
                ),
              ),
            ),
            Expanded(
              child: body(deviceSize),
            ),
          ],
        ),
      ),
    );
  }

  Widget body(Size deviceSize) {
    return Row(
      children: [
        widgetEdgePadding(deviceSize),
        Schedule(
          size: Size(deviceSize.width * scheduleWidthRatio, double.infinity),
        ),
        widgetBetweenPadding(deviceSize),
        Expanded(
          child: Column(
            children: [
              Row(
                children: [
                  Video(
                    size: Size(
                      deviceSize.width * videoWidthRatio,
                      deviceSize.height * videoAndCameraHeightRatio,
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.only(
                      left: deviceSize.width * widgetBetweenWidthPaddingRatio,
                      top: deviceSize.height * widgetBetweenHeightPaddingRatio,
                    ),
                  ),
                  Expanded(
                    child: Camera(
                      size: Size(
                        double.infinity,
                        deviceSize.height * videoAndCameraHeightRatio,
                      ),
                    ),
                  ),
                ],
              ),
              widgetBetweenPadding(deviceSize),
              Lines(
                size: Size(
                  double.infinity,
                  deviceSize.height * linesHeightRatio,
                ),
              ),
              widgetBetweenPadding(deviceSize),
              Expanded(
                child: Row(
                  children: [
                    DailyGraph(
                      size: Size(
                        deviceSize.width * dailyAndWeeklyWidthRatio,
                        double.infinity,
                      ),
                    ),
                    widgetBetweenPadding(deviceSize),
                    WeeklyGraph(
                      size: Size(
                        deviceSize.width * dailyAndWeeklyWidthRatio,
                        double.infinity,
                      ),
                    ),
                    widgetBetweenPadding(deviceSize),
                    const Expanded(
                      child: ProductNumber(),
                    )
                  ],
                ),
              ),
            ],
          ),
        ),
        widgetEdgePadding(deviceSize)
      ],
    );
  }

  Widget widgetBetweenPadding(Size deviceSize) {
    return Padding(
      padding: EdgeInsets.only(
        left: deviceSize.width * widgetBetweenWidthPaddingRatio,
        top: deviceSize.height * widgetBetweenHeightPaddingRatio,
      ),
    );
  }

  Widget widgetEdgePadding(Size deviceSize) {
    return Padding(
      padding: EdgeInsets.only(
        left: deviceSize.width * bodyEdgeWidthPaddingRatio,
      ),
    );
  }
}
